#
# spec file for package stow
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           stow
Version:        2.2.0
Release:        6.5
Url:            http://www.gnu.org/software/stow/
Summary:        Manage the installation of software packages from source
License:        GPL-2.0+
Group:          System/Packages
Source:         http://ftp.gnu.org/gnu/%name/%name-%version.tar.bz2
Source1:        stow-rpmlintrc
Requires:       %install_info_prereq
%perl_requires
Requires:       perl >= 5.6.1
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Test::Output)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
GNU Stow is a symlink farm manager which takes distinct packages of
software and/or data located in separate directories on the
filesystem, and makes them appear to be installed in the same place.
For example, /usr/local/bin could contain symlinks to files within
/usr/local/stow/emacs/bin, /usr/local/stow/perl/bin etc., and
likewise recursively for any other subdirectories such as .../share,
.../man, and so on.

This is particularly useful for keeping track of system-wide and
per-user installations of software built from source, but can also
facilitate a more controlled approach to management of configuration
files in the user's home directory, especially when coupled with
version control systems.

Stow is implemented as a combination of a Perl script providing a CLI
interface, and a backend Perl module which does most of the work.

%package doc
Summary:        Documentation for GNU Stow
Group:          System/Packages
Requires:       %{name} = %{version}

%description doc
Documentation for GNU Stow %{version} in HTML and PDF format.

%prep
%setup

%build
%configure \
    --with-pmdir=%{perl_vendorlib} \
    --docdir=%{_defaultdocdir}/%{name}

%install
make DESTDIR=%buildroot install
rm %buildroot%_docdir/stow/version.texi
install -m 0644 COPYING README AUTHORS ChangeLog doc/ChangeLog.OLD \
                NEWS THANKS TODO \
    %buildroot%_docdir/stow

%check
make test

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
%_bindir/*
%_mandir/man8/stow.*
%_infodir/stow*
%dir %_docdir/stow
%_docdir/stow/COPYING
%_docdir/stow/README
%_docdir/stow/AUTHORS
%_docdir/stow/ChangeLog
%_docdir/stow/ChangeLog.OLD
%_docdir/stow/NEWS
%_docdir/stow/THANKS
%_docdir/stow/TODO
%{perl_vendorlib}/*

%files doc
%defattr(-,root,root)
%_docdir/stow/manual-single.html
%_docdir/stow/manual-split
%_docdir/stow/manual.pdf

%changelog
* Wed Aug  6 2014 aspiers@suse.com
- Rename rpmlintrc as per pkg guideline to %%{name}-rpmlintrc
  (SR #243198)
- Remove old, unused stow.spec.quux
* Thu Sep 12 2013 aspiers@suse.com
- Use %%configure and %%perl_requires macros.
- Don't rm -rf $RPM_BUILD_ROOT.
* Wed Sep 11 2013 aspiers@suse.com
- Run "osc service localrun format_spec_file" on spec file.
* Tue Jan  8 2013 aspiers@suse.com
- split off HTML/PDF docs into -doc subpackage
- fix some rpmlint warnings
* Thu Mar  1 2012 aspiers@suse.com
- improve Description
- fix License field
* Wed Feb 29 2012 aspiers@suse.com
- update to 2.2.0
* Thu Jan 12 2012 Adam Spiers <aspiers@suse.com>
- update to 2.1.3
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Clean up specfile
* Tue May 13 2003 mmj@suse.de
- Remove files we don't package
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 mmj@suse.de
- Only delete info entries when removing last version.
* Fri Feb  7 2003 mmj@suse.de
- Use %%install_info macro
- Cleanup the build root
* Mon Oct 28 2002 mmj@suse.de
- Initial addition, version 1.3.3
